#
# spec file for package ocaml
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Andrew Psaltis <ampsaltis at gmail dot com>
# Copyright (c) 2011 Andrew Psaltis <ampsaltis at gmail dot com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define ocaml_base_version 4.05
#
%define do_opt 0
# This ensures that the find_provides/find_requires calls ocamlobjinfo correctly.
%global __ocaml_requires_opts -c -f "%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte"
%global __ocaml_provides_opts -f "%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte"
# macros to be set in prjconf:
#Macros:
#_with_ocaml_force_enable_ocaml_opt 1
#_with_ocaml_force_disable_ocaml_opt 1
#_with_ocaml_make_testsuite 1
%bcond_with ocaml_force_enable_ocaml_opt
%bcond_with ocaml_force_disable_ocaml_opt
%bcond_with ocaml_make_testsuite
%if %{with ocaml_force_enable_ocaml_opt}
%define do_opt 1
%endif
%if %{without ocaml_force_enable_ocaml_opt}
%ifarch %{arm} aarch64 %{ix86} ppc ppc64 ppc64le s390x x86_64
%define do_opt 1
%endif
%endif
#
%if %{with ocaml_force_disable_ocaml_opt}
%define do_opt 0
%endif
Name:           ocaml
Version:        4.05.0
Release:        lp150.3.1
Summary:        OCaml Compiler and Programming Environment
License:        QPL-1.0 AND SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/OCaml
Url:            http://www.ocaml.org
Source0:        http://caml.inria.fr/pub/distrib/ocaml-%{ocaml_base_version}/ocaml-%{version}.tar.xz
Source1:        ocaml-findlib.rpm.prov_req.attr.sh
Source2:        rpmlintrc
Patch0:         ocaml-3.00-camldebug_el.patch
Patch1:         ocamldoc-man-th.patch
Patch2:         ocaml-3.04-ocamltags--no-site-start.patch
# FIX-UPSTREAM pass RPM_OPT_FLAGS to build
Patch4:         ocaml-configure-Allow-user-defined-C-compiler-flags.patch
Patch5:         ocaml-3.08.3-gcc4.patch
Patch7:         ocaml-3.09-emacs_localcompile.patch
Patch8:         ocaml-4.05.0-CVE-2018-9838.patch
# This gets ocamlobjinfo to work with .cmxs files
BuildRequires:  binutils-devel
BuildRequires:  emacs-nox
BuildRequires:  fdupes
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
Requires:       ocaml(runtime) = %{version}-%{release}
Obsoletes:      ocaml-docs
Provides:       ocaml(compiler) = %{version}
Provides:       ocaml(ocaml_base_version) = %{ocaml_base_version}
%if %{do_opt}
Requires:       gcc
Provides:       ocaml(ocaml.opt) = %{version}
%endif

%description
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package comprises two batch compilers (a fast bytecode compiler
and an optimizing native-code compiler), an interactive top level
system, Lex&Yacc tools, a replay debugger, and a comprehensive library.

%package       rpm-macros
Summary:        RPM macros for building OCaml source packages
License:        QPL-1.0 AND SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/OCaml

%description       rpm-macros
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains a set of helper macros to unify common code used
in ocaml spec files.

%package runtime
Summary:        OCaml runtime environment
License:        QPL-1.0
Group:          Development/Languages/OCaml
Provides:       ocaml(runtime) = %{version}-%{release}

%description runtime
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains the runtime environment needed to run OCaml
bytecode.

%package source
Summary:        Source code for OCaml libraries
License:        QPL-1.0 AND SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/OCaml

%description source
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains source code for OCaml libraries.

%package x11
Summary:        X11 support for OCaml
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/OCaml

%description x11
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains X11 support for OCaml.

%package ocamldoc
Summary:        Documentation generator for OCaml
License:        QPL-1.0
Group:          Development/Languages/OCaml
Requires:       ocaml = %{version}

%description ocamldoc
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains a documentation generator for OCaml.

%package emacs
Summary:        Emacs mode for OCaml
License:        GPL-2.0+
Group:          Development/Languages/OCaml
Requires:       emacs
Requires:       ocaml = %{version}
Provides:       caml-mode

%description emacs
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package provides Emacs mode for OCaml.

%package compiler-libs
Summary:        Libraries used internal to the OCaml Compiler
License:        QPL-1.0
Group:          Development/Languages/OCaml
Requires:       ncurses-devel

%description compiler-libs
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains several modules used internally by the OCaml
compilers. They are not needed for normal OCaml development, but may
be helpful in the development of certain applications.

%package compiler-libs-devel
Summary:        Libraries used internal to the OCaml Compiler
License:        QPL-1.0
Group:          Development/Languages/OCaml
Requires:       ocaml-compiler-libs = %{version}

%description compiler-libs-devel
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

This package contains libraries and signature files for developing
applications that use Ocaml.

%prep
: do_opt %{do_opt}
%autosetup -p1

%build
%ifarch %{ix86}
# Default OPT flags for these architectures use -fomit-frame-pointer,
# which gets in the way of some of the profiling done within.
OUR_OPT_FLAGS="`echo '%{optflags}' | sed 's/-fomit-frame-pointer//g'`"
%else
OUR_OPT_FLAGS="%{optflags}"
%endif

CFLAGS="$OUR_OPT_FLAGS -DUSE_INTERP_RESULT" \
./configure -bindir %{_bindir} \
            -libdir %{_libdir}/ocaml \
            -no-cplugins \
            -mandir %{_mandir} \
            -x11include %{_includedir} \
            -x11lib %{_libdir}

%if %{do_opt}
# build using native-code compilers (equivalent to `make world opt opt.opt`)
make world.opt \
%else
# build bytecode compiler
make world \
%endif
	BYTECCRPATH= \
	NATIVECCRPATH= \
	MKSHAREDLIBRPATH=

%install
make install \
     DESTDIR=%{buildroot}

if test -f %{buildroot}%{_libdir}/ocaml/libasmrun_pic.a
then
	cp -av \
	--remove-destination \
	%{buildroot}%{_libdir}/ocaml/libasmrun_pic.a \
	%{buildroot}%{_libdir}/ocaml/libasmrun.a
fi
EMACS_SITE_LISP=%{_datadir}/emacs/site-lisp
pushd emacs
  make install DESTDIR=%{buildroot} EMACSDIR=%{buildroot}${EMACS_SITE_LISP}
  make install-ocamltags SCRIPTDIR=%{buildroot}${EMACS_SITE_LISP}
popd

# fix bnc#411232
echo '(load "ocaml.el" nil t t)' >%{buildroot}${EMACS_SITE_LISP}/suse-start-ocaml.el
tee %{buildroot}${EMACS_SITE_LISP}/%{name}.el <<EOF
(autoload 'caml-mode "caml" "Caml editing mode" t)
(add-hook 'caml-mode-hook 'font-lock-mode)
(add-to-list 'auto-mode-alist '("\\\\.mli?$" . caml-mode))
EOF
#' # restore highlighting context in vim

export EXCLUDE_FROM_STRIP="ocamldebug ocamlbrowser"

# Install the compiler libs
install -d %{buildroot}%{_libdir}/ocaml/compiler-libs
cp -a typing/ utils/ parsing/ %{buildroot}%{_libdir}/ocaml/compiler-libs
%fdupes %{buildroot}

# rpmlint ...
chmod -v a+x %{buildroot}%{_libdir}/ocaml/camlheader
# preserve .cmxs and .so
find %{buildroot} \( \
	-name '*.a' -o \
	-name '*.cma' -o \
	-name '*.cmi' -o \
	-name '*.cmo' -o \
	-name '*.cmt' -o \
	-name '*.cmti' -o \
	-name '*.cmx' -o \
	-name '*.cmxa' -o \
	-name '*.conf' -o \
	-name '*.h' -o \
	-name '*.hva' -o \
	-name '*.ml' -o \
	-name '*.mli' -o \
	-name '*.mll' -o \
	-name '*.mlp' -o \
	-name '*.mly' -o \
	-name '*.o' -o \
	-name '*.sml' \
	\) -type f -exec chmod -v a-x "{}" \;

# install OCaml macros
mkdir -vp %{buildroot}%{_sysconfdir}/rpm
tee %{buildroot}%{_sysconfdir}/rpm/macros.%{name} <<'_EOF_'
# get rid of /usr/lib/rpm/find-debuginfo.sh
# strip kills the bytecode part of ELF binaries
#
# provide empty _find_debuginfo_dwz_opts
# the .dwz files contains identical contents, which leads to identical
# checksums, which leads to file conflicts due to identical symlinks
%if %{do_opt}
%%ocaml_preserve_bytecode \
	%%{nil}
%%ocaml_native_compiler 1
%%_find_debuginfo_dwz_opts %%{nil}
%else
%%ocaml_preserve_bytecode \
	%%undefine _build_create_debug \
	%%define __arch_install_post export NO_BRP_STRIP_DEBUG=true \
	%%{nil}
%%ocaml_native_compiler 0
%endif

# setup.ml comes from oasis, but this is here for libs oasis depends on
#
# html goes into a separate, browsable dir
# which is also safe regarding wiping due to %%doc macro usage
%%_oasis_docdir_base %%{_datadir}/doc/ocaml
%%_oasis_docdir_dvi   %%{_oasis_docdir_base}/%%{name}
%%_oasis_docdir_html  %%{_oasis_docdir_base}/%%{name}
%%_oasis_docdir_pdf   %%{_oasis_docdir_base}/%%{name}
%%_oasis_docdir_ps    %%{_oasis_docdir_base}/%%{name}
%%oasis_docdir        %%{_oasis_docdir_base}/%%{name}
#
# For now provide a convinience macro which covers also the parent dir
%%oasis_docdir_dvi  %%dir %%{_oasis_docdir_base} \
%%{_oasis_docdir_dvi}
%%oasis_docdir_html %%dir %%{_oasis_docdir_base} \
%%{_oasis_docdir_html}
%%oasis_docdir_pdf  %%dir %%{_oasis_docdir_base} \
%%{_oasis_docdir_pdf}
%%oasis_docdir_ps   %%dir %%{_oasis_docdir_base} \
%%{_oasis_docdir_ps}
#
# various macros to unify setup/build/install
%%oasis_setup \
	oasis setup
%%ocaml_oasis_configure \
ocaml setup.ml -configure \\\
	--psdir          %%{_oasis_docdir_ps} \\\
	--pdfdir         %%{_oasis_docdir_pdf} \\\
	--dvidir         %%{_oasis_docdir_dvi} \\\
	--htmldir        %%{_oasis_docdir_html} \\\
	--docdir         %%{oasis_docdir} \\\
	--localedir      %%{_datadir}/locale \\\
	--datadir        %%{_datadir} \\\
	\\\
	--bindir         %%{_bindir} \\\
	--mandir         %%{_mandir} \\\
	--destdir        %%{buildroot} \\\
	--datarootdir    %%{_datadir} \\\
	--infodir        %%{_infodir} \\\
	--libdir         %%{_libdir} \\\
	--libexecdir     %%{_libexecdir} \\\
	--localstatedir  %%{_localstatedir} \\\
	--sbindir        %%{_sbindir} \\\
	--prefix         %%{_prefix} \\\
	--sysconfdir     %%{_sysconfdir} \\\
	--exec-prefix    %%{_prefix} \\\
	--sharedstatedir %%{_sharedstatedir}
#
%%ocaml_oasis_build \
	ocaml setup.ml -build
%%ocaml_oasis_doc \
	ocaml setup.ml -doc
%%ocaml_oasis_install \
	ocaml setup.ml -install
%%ocaml_oasis_findlib_install \
	export OCAMLFIND_DESTDIR=%%{buildroot}`ocamlc -where` ; \
	export OCAMLFIND_LDCONF=/dev/null ; \
	mkdir -p $OCAMLFIND_DESTDIR ; \
	ocaml setup.ml -install
%%ocaml_oasis_test \
	ocaml setup.ml -test
#
#
_EOF_

tag="ocamlfind"
mkdir -vp %{buildroot}%{_rpmconfigdir}/fileattrs
tee %{buildroot}%{_rpmconfigdir}/fileattrs/${tag}.attr <<_EOF_
%__${tag}_provides %%{_rpmconfigdir}/${tag}.sh -prov
%__${tag}_requires %%{_rpmconfigdir}/${tag}.sh -req
%__${tag}_path     ^%%{_libdir}/ocaml/.*/META$|^%%{_libdir}/ocaml/META$
_EOF_
#
tee %{buildroot}%{_rpmconfigdir}/${tag}.sh < %{SOURCE1}

%files
%doc Changes LICENSE
%{_rpmconfigdir}/fileattrs
%attr(755,root,root) %{_rpmconfigdir}/*.sh
%{_bindir}/*
%{_mandir}/*/*
%{_libdir}/ocaml/*.a
%if %{do_opt}
%{_libdir}/ocaml/*.cmxs
%{_libdir}/ocaml/*.cmxa
%{_libdir}/ocaml/*.cmx
%{_libdir}/ocaml/*.o
%endif
%{_libdir}/ocaml/*.mli
%{_libdir}/ocaml/libcamlrun_shared.so
%if %{do_opt}
%{_libdir}/ocaml/libasmrun_shared.so
%endif
%{_libdir}/ocaml/vmthreads/*.mli
%{_libdir}/ocaml/vmthreads/*.a
%if %{do_opt}
%{_libdir}/ocaml/threads/*.a
%{_libdir}/ocaml/threads/*.cmxa
%{_libdir}/ocaml/threads/*.cmx
%endif
%{_libdir}/ocaml/caml
%{_libdir}/ocaml/Makefile.config
%{_libdir}/ocaml/VERSION
%{_libdir}/ocaml/extract_crc
%{_libdir}/ocaml/camlheader
%{_libdir}/ocaml/camlheader_ur
%{_libdir}/ocaml/expunge
%{_libdir}/ocaml/ld.conf
%{_libdir}/ocaml/objinfo_helper
%exclude %{_libdir}/ocaml/graphicsX11.mli
%exclude %{_bindir}/ocamlrun
%exclude %{_bindir}/ocamldoc*
%exclude %{_libdir}/ocaml/ocamldoc

%files rpm-macros
%dir %{_sysconfdir}/rpm
%config %{_sysconfdir}/rpm/*

%files runtime
%{_bindir}/ocamlrun
%dir %{_libdir}/ocaml
%{_libdir}/ocaml/*.cmo
%{_libdir}/ocaml/*.cmi
%{_libdir}/ocaml/*.cmt
%{_libdir}/ocaml/*.cmti
%{_libdir}/ocaml/*.cma
%{_libdir}/ocaml/stublibs
%dir %{_libdir}/ocaml/vmthreads
%{_libdir}/ocaml/vmthreads/*.cmi
%{_libdir}/ocaml/vmthreads/*.cma
%{_libdir}/ocaml/vmthreads/*.cmti
%dir %{_libdir}/ocaml/threads
%{_libdir}/ocaml/threads/*.cmi
%{_libdir}/ocaml/threads/*.cma
%{_libdir}/ocaml/threads/*.cmti
%exclude %{_libdir}/ocaml/graphicsX11.cmi
%doc LICENSE Changes

%files x11
%{_libdir}/ocaml/graphicsX11.cmi
%{_libdir}/ocaml/graphicsX11.mli

%files source
%{_libdir}/ocaml/*.ml

%files ocamldoc
%{_bindir}/ocamldoc*
%{_libdir}/ocaml/ocamldoc
%doc ocamldoc/Changes.txt

%files emacs
%doc emacs/README
%dir %{_datadir}/emacs
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/site-lisp/*

%files compiler-libs
%doc LICENSE
%{_libdir}/ocaml/compiler-libs
%if %{do_opt}
%exclude %{_libdir}/ocaml/compiler-libs/*.cmx
%exclude %{_libdir}/ocaml/compiler-libs/*.o
%exclude %{_libdir}/ocaml/compiler-libs/*/*.cmx
%exclude %{_libdir}/ocaml/compiler-libs/*/*.o
%endif
%exclude %{_libdir}/ocaml/compiler-libs/*.mli
%exclude %{_libdir}/ocaml/compiler-libs/*/*.mli
%exclude %{_libdir}/ocaml/compiler-libs/*/*.ml

%files compiler-libs-devel
%doc LICENSE
%if %{do_opt}
%{_libdir}/ocaml/compiler-libs/*.cmx
%{_libdir}/ocaml/compiler-libs/*.o
%{_libdir}/ocaml/compiler-libs/*/*.cmx
%{_libdir}/ocaml/compiler-libs/*/*.o
%endif
%{_libdir}/ocaml/compiler-libs/*.mli
%{_libdir}/ocaml/compiler-libs/*/*.ml
%{_libdir}/ocaml/compiler-libs/*/*.mli

%if %{with ocaml_make_testsuite}
%check
make %{?_smp_mflags} -C testsuite clean
if make -C testsuite all
then
	: passed
else
	: failed
fi
%endif

%changelog
* Tue Apr 24 2018 kstreitova@suse.com
- update ocaml-4.05.0-CVE-2018-9838.patch that causes "undefined
  reference to `caml_umul_overflow`" build failure. Replace this
  function that is not available in ocaml 4.05 (added in ocaml
  4.06) with the present caml_ba_multov() that is basically the
  same [bnc#1088591] [CVE-2018-9838]
* Fri Apr 13 2018 kstreitova@suse.com
- add ocaml-4.05.0-CVE-2018-9838.patch to fix integer overflows
  when unmarshaling a bigarray. Malicious or corrupted marshaled
  data can result in a bigarray with impossibly large dimensions
  that cause overflow when computing the in-memory size of the
  bigarray. Disaster ensues when the data is read in a too small
  memory area [bnc#1088591] [CVE-2018-9838]
* Wed Apr  4 2018 kstreitova@suse.com
- run spec-cleaner
- update URL to www.ocaml.org
- the language is officially called OCaml and not Objective Caml,
  rename it in summaries and descriptions
- tweak summaries and descriptions
- remove definition of %%{_rpmconfigdir} macro - it should be
  defined on all distros by default now
* Wed Apr  4 2018 ohering@suse.de
- Remove info and html documentation because it is not as free
  as it should be. Drop ocaml-docs package. (bsc#1080640)
- adjust ocaml-3.09-emacs_localcompile.patch and
  ocaml-3.08.3-gcc4.patch for autosetup
* Thu Aug 10 2017 ohering@suse.de
- Provide ocaml(ocaml_base_version) for camlp4
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- update version 4.05.0
  * http://caml.inria.fr/pub/distrib/ocaml-4.05/notes/Changes
- build with -no-cplugins (CVE-2017-9772)
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Tue Jun  6 2017 ohering@suse.de
- Clear _find_debuginfo_dwz_opts to avoid file conflicts due
  to identical contents in .dwz sections
* Wed May 31 2017 ohering@suse.de
- Install libasmrun_pic to fix build with gcc7
* Thu Jun 30 2016 ohering@suse.de
- Correct .TH macro creation in ocamldoc (ocaml#7281)
  ocamldoc-man-th.patch
* Thu Jun 16 2016 ohering@suse.de
- Install ocamltags in emacs site-lisp, do not add a shebang anymore
* Mon Jun 13 2016 ohering@suse.de
- Provide various macros to unify oasis ocaml setup.ml $cmd usage
* Tue Jun  7 2016 ohering@suse.de
- ocaml-compiler-libs requires ncurses-devel for some bytecode
  compilation
* Fri May 27 2016 ohering@suse.de
- Add Provides/Requires for ocamlfind() from META files
* Wed May 18 2016 ohering@suse.de
- update version 4.03.0 (fate#320836)
  * http://caml.inria.fr/pub/distrib/ocaml-4.03/notes/Changes
  drop ocaml-ppc64.patch
  drop ocaml-ppc64le.patch
  drop ocaml-arch-rlimit-stacksize.patch
  drop ocaml-4.02.3-bufferoverflow_infoleak.patch
* Wed May  4 2016 kstreitova@suse.com
- add ocaml-4.02.3-bufferoverflow_infoleak.patch to prevent buffer
  overflow and information leak [bsc#977990], [CVE-2015-8869]
- use spec-cleaner to clean the specfile
* Wed Nov 11 2015 ohering@suse.de
- Increase rlimit stack size on ppc64
  ocaml-arch-rlimit-stacksize.patch
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Wed Sep 16 2015 ohering@suse.de
- update version 4.02.3
  * http://caml.inria.fr/pub/distrib/ocaml-4.02/notes/Changes
* Tue Aug  4 2015 kstreitova@suse.com
- use spec-cleaner
* Tue Jun 23 2015 ohering@suse.de
- update version 4.02.2
  * http://caml.inria.fr/pub/distrib/ocaml-4.02/notes/Changes
* Thu Oct 23 2014 ohering@suse.de
- Recognize macros provided by prjconf to disable ocamlopt and
  run testsuite
* Thu Oct 23 2014 ohering@suse.de
- New subpackage ocaml-rpm-macros
* Wed Oct 22 2014 ohering@suse.de
- update version 4.02.1
  * http://caml.inria.fr/pub/distrib/ocaml-4.02/notes/Changes
* Mon Oct 20 2014 ohering@suse.de
- Update ppc64/ppc64le patch (bnc#901836)
* Wed Oct  8 2014 ohering@suse.de
- update version 4.02.0
  * http://caml.inria.fr/pub/distrib/ocaml-4.02/notes/Changes
  drop ocaml-rpath.patch, can be done with make args
  drop ocaml-yacc-Use-mkstemp-instead-of-mktemp.patch, upstream
  drop unused postscript docs
- Removed Camlp4 and Labltk from the distribution, now available as
  third-party software.
* Wed Aug 27 2014 ohering@suse.de
- Require as/gcc for ocamlopt (bnc#891177)
* Thu May  1 2014 dvaleev@suse.com
- Enable opt for ppc64le (ocaml-ppc64le.patch)
* Sat Feb  1 2014 ohering@suse.de
- Disable opt on aarch64
* Thu Jan 30 2014 ohering@suse.de
- Provide ocaml(ocaml.opt)==version if available
* Fri Dec  6 2013 matz@suse.de
- Disable opt on ppc64le (ocaml-ppc64.patch doesn't support ELVv2)
* Thu Sep 19 2013 ohering@suse.de
- update version 4.01.0
  * http://caml.inria.fr/pub/distrib/ocaml-4.01/notes/Changes
  add ocaml-yacc-Use-mkstemp-instead-of-mktemp.patch
  rename obsolete ocaml-rpmoptflags.patch to
  ocaml-configure-Allow-user-defined-C-compiler-flags.patch
  remove obsolete ocaml-tcl86.patch
  remove obsolete ocaml-3.08.3.patch
* Tue Sep 10 2013 guillaume@opensuse.org
- Fix ARM build
* Thu Aug  1 2013 max@suse.com
- Added ocaml-tcl86.patch to fix build with Tcl 8.6.
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Fri Mar 22 2013 dvaleev@suse.com
- refresh ocaml-ppc64.patch
- increase stack size for ppc64
- package back *cmxs files for ppc
* Thu Feb 21 2013 ohering@suse.de
- add hard requires ocaml-compiler-libs in ocaml-camlp4 in
  versions before 12.1 due to lack of autorequires in old rpm
* Thu Feb 21 2013 ohering@suse.de
- disable opt on ia64
* Fri Feb 15 2013 i@marguerite.su
- update version 4.00.1
  * http://caml.inria.fr/pub/distrib/ocaml-4.00/notes/Changes
- remove ocaml-3.04-info.patch, upstream fixed.
- remove arm-add-type-directive.patch, upstream fixed.
* Mon Jan 14 2013 ohering@suse.de
- change Requires: version-release to just Requires: version
* Wed Jan  2 2013 ohering@suse.de
- update specfile to handle disabled do_opt variable
* Wed Jun 27 2012 dvaleev@suse.com
- refresh ppc64 patch
- Link dllthreads.so with -lpthread so that pthread_atfork
  is included statically.
* Thu May 10 2012 cfarrell@suse.com
- license update: QPL-1.0 and SUSE-LGPL-2.0-with-linking-exception
  Use SPDX format (http://www.spdx.org/licenses). Where there is no
  suitable shortname available on spdx.org check the spreadsheet linked at
  license.opensuse.org
* Tue Jan 31 2012 dvaleev@suse.com
- *.cmxs doesn't built for ppc
* Mon Dec 19 2011 coolo@suse.com
- fix Source references to contain original upstream
* Sun Nov 13 2011 dmueller@suse.de
- add add .type directive for code symbols (needed on arm)
* Tue Nov  8 2011 dvaleev@suse.com
- enable ppc64 build
* Thu Sep 15 2011 ampsaltis@gmail.com
- Explicitly require the ocaml-runtime package in the ocaml package
* Thu Sep 15 2011 ampsaltis@gmail.com
- The ocaml package does not provide the runtime any more.
* Fri Jul 22 2011 ampsaltis@gmail.com
- Unremove code block regarding removing -fomit-frame-pointer within RPM_OPT_FLAGS for ix86 architectures
* Thu Jul 21 2011 ampsaltis@gmail.com
- Enable optimizations (Fedora does this)
- More cleanup done
* Thu Jul 21 2011 ampsaltis@gmail.com
- Clean up spec file
- Remove ocaml-3.12-fix-size-directive.patch
* Tue Jul  5 2011 ampsaltis@gmail.com
- New upstream version 3.12.1, providing many bugfixes.
- ocaml-3.12-fix-size-directive.patch is no longer needed.
* Sun Jun 19 2011 ampsaltis@gmail.com
- Add compiler library packages
* Sun Jun 19 2011 ampsaltis@gmail.com
- Obsolete old "camlp4" package
* Fri Jun 17 2011 ampsaltis@gmail.com
- Split (and rename) camlp4 package.  Add provide for consistency.
- Decomment some stuff.
* Fri May 27 2011 ampsaltis@gmail.com
- Make the spec work with older versions of RPM
- Split some parts of packages for devel-ness
* Tue May 24 2011 coolo@novell.com
- add provides required by the rpm-4.9 auto provides
* Mon May 23 2011 coolo@novell.com
- fix for last change to also include interpreter
* Sat May 21 2011 jslaby@suse.de
- fix build with rpm 4.9.0
* Wed Apr 27 2011 vcizek@novell.com
- license correction to GPLv2 and QPL
- removed author from spec
* Tue Apr 26 2011 idoenmez@novell.com
- Add ocaml-3.12-fix-size-directive.patch:
  incorrect .size directives generated for x86-32 and x86-64
* Tue Aug 24 2010 anicka@suse.cz
- update to 3.12.0
  * While fixing PR#4824, also corrected a gaping hole in the type checker,
  which allowed instantiating separately object parameters and instance
  variables in an interface. This hole was here since the beginning of
  ocaml, and as a result many programs using object inheritance in a non
  trivial way will need to be corrected. You can look at lablgtk2 for an
  example.
  * new language features, bugfixes
* Mon Jan 11 2010 vuntz@opensuse.org
- Remove unneeded gtk-devel BuildRequires.
* Fri Dec 11 2009 anicka@suse.cz
- update to 1.11.1
  * bug fixes
  * Improved wording of various error messages
  * Support for 64-bit mode in Solaris/x86 (PR#4670).
* Tue Jun  9 2009 coolo@novell.com
- filter out fomit-frame-pointer from rpm_opt_flags to fix build
* Tue Feb 17 2009 anicka@suse.cz
- update to 1.11.0
  * major relase with many changes, language enhancements and bugfixes
  * backward incompatible changes:
  * Revised -output-obj: the output name
    must now be provided; its extension must be one of .o/.obj,
    .so/.dll, or .c for the bytecode compiler. The compilers can
    now produce a shared library (with all the needed -ccopts/-ccobjs
    options) directly.
  * programs linked with camlp4lib.cma now also need dynlink.cma
- remove type_punning and tk8.5 patches (not needed anymore)
- drop ppc64 patch
- use %%fdupes macro to reduce size of the package
* Thu Jul 24 2008 anicka@suse.cz
- fix loading caml-mode in emacs (bnc#411232)
* Thu Jul 10 2008 olh@suse.de
- build also on ppc64 (fate#304103)
* Wed Apr  9 2008 anicka@suse.cz
- update to 3.10.2
  * PR#1217 (partial) Typo in ocamldep man page
  * PR#3952 (partial) ocamlopt: allocation problems on ARM
  * PR#4339 (continued) ocamlopt: problems on HPPA
  * PR#4455 str.mli not installed under Windows
  * PR#4473 crash when accessing float array with polymorphic method
  * PR#4480 runtime would not compile without gcc extensions
  * PR#4481 wrong typing of exceptions with object arguments
  * PR#4490 typo in error message
  * Random crash on 32-bit when major_heap_increment >= 2^22
  * Big performance bug in Weak hashtables
  * Small bugs in the make-package-macosx script
  * Bug in typing of polymorphic variants (reported on caml-list)
* Mon Apr  7 2008 anicka@suse.cz
- fix build for tk 8.5
* Mon Mar 10 2008 anicka@suse.cz
- update to 3.10.1
  - made configure script work on PlayStation 3
  - ARM port: brought up-to-date for Debian 4.0 (Etch)
  - many other small changes and bugfixes in camlp4, ocamlbuild, labltk,
  emacs files,
  - Added virtual instance variables in classes "val virtual v : t"
  * Changed the behaviour of instance variable overriding; the new
  definition replaces the old one, rather than creating a new
  variable.
  - ocamlbuild: compilation manager for OCaml applications and libraries.
  See draft documentation at http://gallium.inria.fr/~pouillar/
  * Camlp4: heavily revised implementation, new API.
  - Faster type-checking of functor applications.
  - Referencing an interface compiled with -rectypes from a module
    not compiled with -rectypes is now an error.
  - Revised the "fragile matching" warning.
  - Print a stack backtrace on an uncaught exception.
  (Compile and link with ocamlopt -g; execute with OCAMLRUNPARAM=b.)
  Supported on Intel/AMD in 32 and 64 bits, PPC in 32 and 64 bits.
  - Stack overflow detection on MS Windows 32 bits (courtesy O. Andrieu).
  - Stack overflow detection on MacOS X PPC and Intel.
  - Intel/AMD 64 bits: generate position-independent code by default.
  - Fixed bug involving -for-pack and missing .cmx files (PR#4124).
  - Fixed bug causing duplication of literals  (PR#4152).
  - C/Caml interface functions take "char const *" arguments
  instead of "char *" when appropriate.
  - Faster string comparisons (fast case if strings are ==).
* Wed Nov 28 2007 ro@suse.de
- added -O0 to optflags for now on x86 (#343760)
* Sun Nov  4 2007 ro@suse.de
- updated rpmlintrc
* Fri Jun 15 2007 ro@suse.de
- clean up specfile a bit (thanks to dirk stoecker)
* Wed May 16 2007 ro@suse.de
- split up package similar to f-e
- update to 3.09.3
  * featurelist
  - ocamldoc: name resolution in cross-referencing {!name}: if name is not
    found, then it is searched in the parent module/class, and in the parent
    of the parent, and so on until it is found.
  - ocamldoc: new option -short-functors to use a short form to display
    functors in html generator PR#4017
  - ocamlprof: added "-version" option
  - ported to MacOS X on Intel PR#3985
  - configure: added support for GNU Hurd PR#3991
  - otherlibs/labltk: browser uses menu bars instead of menu buttons
  - Introduction of private row types, for abstracting the row in object
    and variant types.
  - configure: find X11 config in some 64-bit Linux distribs
  - ocamldoc: (**/**) can be canceled with another (**/**) PR#3665
  - graphics: added resize_window
  - graphics: check for invalid arguments to drawing primitives PR#3595
  - ocamlbrowser: use windows subsystem on mingw
  * disruptive changes
  * Revised implementation of the -pack option (packing of several compilation
    units into one).  The .cmx files that are to be packed with
    "ocamlopt -pack -o P.cmx" must be compiled with "ocamlopt -for-pack P".
    In exchange for this additional constraint, ocamlopt -pack is now
    available on all platforms (no need for binutils).
  * Fixed wrong evaluation order for arguments to certain inlined functions.
* Thu Mar 29 2007 rguenther@suse.de
- add emacs site-lisp directories
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel and ncurses-devel BuildRequires
* Thu Aug 17 2006 cthiel@suse.de
- fix build with X.Org 7.1
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu May 12 2005 ro@suse.de
- update to 3.08.3
- reduce register pressure in bng_ia32.c (thanks to matz)
* Tue Sep 14 2004 jj@suse.de
- version update (done by pthomas)
* Wed Apr 28 2004 ro@suse.de
- added -fno-strict-aliasing also to native build
* Mon Apr 19 2004 mmj@suse.de
- declare void functions as such
* Sat Jan 10 2004 adrian@suse.de
- use x-devel-packages
* Sat Jun 21 2003 mmj@suse.de
- Own all dirs
* Wed May 21 2003 coolo@suse.de
- fix man page installation
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 mmj@suse.de
- head -1 is head -n 1 with the new coreutils
* Tue Feb 11 2003 mmj@suse.de
- Use %%install_info macro [#23440]
* Tue Sep 17 2002 uli@suse.de
- update -> 3.0.6 (needed for mldonkey)
* Mon Jun 17 2002 meissner@suse.de
- copy over config.* from libtool repository and other ppc64 fixes.
* Mon May 27 2002 ro@suse.de
- fix installation in camlp4 directory (bindir was without
  buildroot prefix)
* Fri May 24 2002 mmj@suse.de
- Disabling build of optional architecture specific stuff on plat-
  forms where ocaml does not procide the necessary asm parts.
* Wed May 15 2002 schwab@suse.de
- Fix neededforbuild.
* Mon May 13 2002 mmj@suse.de
- Update to 3.04, maily bugfix release
* Tue Jan 15 2002 schwab@suse.de
- Fix for ia64.
* Thu Aug 16 2001 grimmer@suse.de
- initial SuSE package (version 3.02), added to be able to build
  package "unison"
- spec file derived from Mandrake Linux source RPM (thanks, pixel!)
